@@ -17,6 +17,7 @@ from metlog.path import DottedNameResolver
 from textwrap import dedent
 import ConfigParser
 import StringIO
+import copy
 import os
 import re
 
@@ -151,7 +152,9 @@ def client_from_dict_config(config, client=None, clear_global=False):
       All remaining key-value pairs in the sender config dict will be passed as
       keyword arguments to the sender constructor.
     """
-    config = nest_prefixes(config)
+    # Make a deep copy of the configuration so that subsequent uses of
+    # the config won't blow up
+    config = nest_prefixes(copy.deepcopy(config))
 
     sender_config = config.get('sender', {})
     logger = config.get('logger', '')
@@ -187,12 +190,12 @@ def client_from_dict_config(config, client=None, clear_global=False):
         client.setup(sender, logger, severity, disabled_timers, filters)
 
     # initialize plugins and attach to client
-    for plugin_name, plugin_spec in plugins_data.items():
+    for section_name, plugin_spec in plugins_data.items():
         # each plugin spec is a 2-tuple: (dotted_name, cfg)
         plugin_config = plugin_spec[1]
         plugin_override = plugin_config.pop('override', False)
         plugin_fn = resolver.resolve(plugin_spec[0])(plugin_config)
-        client.add_method(plugin_name, plugin_fn, plugin_override)
+        client.add_method(plugin_fn, plugin_override)
 
     return client
 
